@@ -1,14 +1,16 @@
 from beta9 import env
 from beta9.abstractions import experimental
 from beta9.abstractions.container import Container
+from beta9.abstractions.endpoint import ASGI as asgi
 from beta9.abstractions.endpoint import Endpoint as endpoint
 from beta9.abstractions.function import Function as function
+from beta9.abstractions.function import Schedule as schedule
 from beta9.abstractions.image import Image
 from beta9.abstractions.map import Map
 from beta9.abstractions.output import Output
 from beta9.abstractions.queue import SimpleQueue as Queue
 from beta9.abstractions.taskqueue import TaskQueue as task_queue
-from beta9.abstractions.volume import Volume
+from beta9.abstractions.volume import CloudBucket, CloudBucketConfig, Volume
 from beta9.type import GpuType, PythonVersion, QueueDepthAutoscaler
 
 __all__ = [
@@ -16,9 +18,12 @@ __all__ = [
     "Image",
     "Queue",
     "Volume",
+    "CloudBucket",
+    "CloudBucketConfig",
     "task_queue",
     "function",
     "endpoint",
+    "asgi",
     "Container",
     "env",
     "PythonVersion",
@@ -26,4 +31,5 @@ __all__ = [
     "Output",
     "QueueDepthAutoscaler",
     "experimental",
+    "schedule",
 ]
